@@ -22,7 +22,7 @@
 #include <tqlayout.h>
 #include <tqlineedit.h>
 
-// KDE includes
+// TDE includes
 #include <tdelocale.h>
 #include <tdelistview.h>
 #include <kpushbutton.h>
@@ -95,20 +95,20 @@ HelpDialog::HelpDialog( HelpDialogData* data, TQWidget* parent,
     HelpDialogLayout->addLayout( Layout1 );
 
     // signals and slots connections
-    connect( buttonClose, TQT_SIGNAL( clicked() ), this, TQT_SLOT( accept() ) );
-    connect( buttonAdd, TQT_SIGNAL( clicked() ), this, TQT_SLOT( execute() ) );
-    connect( list, TQT_SIGNAL( executed(TQListViewItem*) ), this, TQT_SLOT( execute() ) );
-    connect( comboHeadline, TQT_SIGNAL( activated(int) ), this, TQT_SLOT(updateItems() ) );
+    connect( buttonClose, TQ_SIGNAL( clicked() ), this, TQ_SLOT( accept() ) );
+    connect( buttonAdd, TQ_SIGNAL( clicked() ), this, TQ_SLOT( execute() ) );
+    connect( list, TQ_SIGNAL( executed(TQListViewItem*) ), this, TQ_SLOT( execute() ) );
+    connect( comboHeadline, TQ_SIGNAL( activated(int) ), this, TQ_SLOT(updateItems() ) );
     
     m_data = data;
-    connect( m_data, TQT_SIGNAL( updateItems() ), this, TQT_SLOT( updateItems() ) );
-    connect( m_data, TQT_SIGNAL( updateHeadline() ), this, TQT_SLOT( updateHeadline() ) );
+    connect( m_data, TQ_SIGNAL( updateItems() ), this, TQ_SLOT( updateItems() ) );
+    connect( m_data, TQ_SIGNAL( updateHeadline() ), this, TQ_SLOT( updateHeadline() ) );
 }
 
 HelpDialog::~HelpDialog()
 {
-    disconnect( m_data, TQT_SIGNAL( updateItems() ), this, TQT_SLOT( updateItems() ) );
-    disconnect( m_data, TQT_SIGNAL( updateHeadline() ), this, TQT_SLOT( updateHeadline() ) );
+    disconnect( m_data, TQ_SIGNAL( updateItems() ), this, TQ_SLOT( updateItems() ) );
+    disconnect( m_data, TQ_SIGNAL( updateHeadline() ), this, TQ_SLOT( updateHeadline() ) );
 }
 
 void HelpDialog::execute()
@@ -149,3 +149,4 @@ void HelpDialog::updateHeadline()
             comboHeadline->insertItem( ic[it.key()], it.key() );    
 }
 
+#include "helpdialog.moc"
