@@ -15,7 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-// QT includes
+// TQt includes
 #include <tqcursor.h>
 #include <tqdir.h>
 #include <tqdragobject.h>
@@ -23,7 +23,7 @@
 #include <tqpalette.h>
 #include <tqregexp.h>
 
-// KDE includes
+// TDE includes
 #include <tdeapplication.h>
 #include <kdirlister.h>
 #include <kiconloader.h>
@@ -58,9 +58,9 @@ KMyListBox::KMyListBox(TQWidget* parent, const char* name, WFlags fl)
     setAcceptDrops( true );
     setSelectionMode(Extended); // was extended before 2.9.0
 
-    connect( this, TQT_SIGNAL(doubleClicked(TQListBoxItem*)), this, TQT_SLOT(openFile(TQListBoxItem*)));
-    connect( this, TQT_SIGNAL(returnPressed(TQListBoxItem*)), this, TQT_SLOT(openFile(TQListBoxItem*)));
-    connect( label, TQT_SIGNAL( leftClickedURL() ), this, TQT_SIGNAL( addFiles() ) );
+    connect( this, TQ_SIGNAL(doubleClicked(TQListBoxItem*)), this, TQ_SLOT(openFile(TQListBoxItem*)));
+    connect( this, TQ_SIGNAL(returnPressed(TQListBoxItem*)), this, TQ_SLOT(openFile(TQListBoxItem*)));
+    connect( label, TQ_SIGNAL( leftClickedURL() ), this, TQ_SIGNAL( addFiles() ) );
     
     positionLabel();
 }
@@ -335,9 +335,9 @@ void KMyListBox::select( TQListBoxItem* item )
 void KMyListBox::preview( KURL::List list )
 {
     TDEIO::PreviewJob* job = TDEIO::filePreview( list, previewSize, previewSize, 0, 100, false, true, 0 );
-    connect( job, TQT_SIGNAL( gotPreview( const KFileItem*, const TQPixmap &) ), this, TQT_SLOT( previewDone( const KFileItem*, const TQPixmap &) ) );
-    connect( job, TQT_SIGNAL( failed( const KFileItem*)), this, TQT_SLOT( previewFailed( const KFileItem* ) ));
-    connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ), this, TQT_SLOT( previewFinished() ) );
+    connect( job, TQ_SIGNAL( gotPreview( const KFileItem*, const TQPixmap &) ), this, TQ_SLOT( previewDone( const KFileItem*, const TQPixmap &) ) );
+    connect( job, TQ_SIGNAL( failed( const KFileItem*)), this, TQ_SLOT( previewFailed( const KFileItem* ) ));
+    connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( previewFinished() ) );
     TDEApplication::setOverrideCursor( TQt::waitCursor );
 }
 
