@@ -36,7 +36,7 @@
 #include "krenamedcop.h"
 #include "profiledlg.h"
 
-// KDE includes
+// TDE includes
 #include <dcopclient.h>
 #include <tdeaboutapplication.h>
 #include <tdeapplication.h>
@@ -55,7 +55,7 @@
 #include <tdelocale.h>
 #include <tdeio/netaccess.h>
 
-// QT includes
+// TQt includes
 #include <tqbuttongroup.h>
 #include <tqcursor.h>
 #include <tqgrid.h>
@@ -120,47 +120,47 @@ void KRenameImpl::setup( bool wizardmode )
     setupPages();
     updateCount();
 
-    connect( buttonAdd, TQT_SIGNAL( clicked() ), this, TQT_SLOT( addFile() ));
-    connect( buttonRemoveAll, TQT_SIGNAL( clicked()), this, TQT_SLOT( clearList() ));
-    connect( buttonRemove, TQT_SIGNAL( clicked()), this, TQT_SLOT( removeFile() ));
-    connect( buttonHelp, TQT_SIGNAL( clicked()), this, TQT_SLOT( showTokenHelp() ));
-    connect( finishButton, TQT_SIGNAL( clicked()), this, TQT_SLOT( start() ));
+    connect( buttonAdd, TQ_SIGNAL( clicked() ), this, TQ_SLOT( addFile() ));
+    connect( buttonRemoveAll, TQ_SIGNAL( clicked()), this, TQ_SLOT( clearList() ));
+    connect( buttonRemove, TQ_SIGNAL( clicked()), this, TQ_SLOT( removeFile() ));
+    connect( buttonHelp, TQ_SIGNAL( clicked()), this, TQ_SLOT( showTokenHelp() ));
+    connect( finishButton, TQ_SIGNAL( clicked()), this, TQ_SLOT( start() ));
 
-    connect( checkExtension, TQT_SIGNAL( clicked()), this, TQT_SLOT( enableControls() ));
-    connect( optionRename, TQT_SIGNAL( clicked()), this, TQT_SLOT( enableControls() ));
-    connect( optionMove, TQT_SIGNAL( clicked()), this, TQT_SLOT( enableControls() ));
-    connect( optionCopy, TQT_SIGNAL( clicked()), this, TQT_SLOT( enableControls() ));
-    connect( optionLink, TQT_SIGNAL( clicked()), this, TQT_SLOT( enableControls() ));
-    connect( checkUndoScript, TQT_SIGNAL( clicked()), this, TQT_SLOT( enableControls() ));
+    connect( checkExtension, TQ_SIGNAL( clicked()), this, TQ_SLOT( enableControls() ));
+    connect( optionRename, TQ_SIGNAL( clicked()), this, TQ_SLOT( enableControls() ));
+    connect( optionMove, TQ_SIGNAL( clicked()), this, TQ_SLOT( enableControls() ));
+    connect( optionCopy, TQ_SIGNAL( clicked()), this, TQ_SLOT( enableControls() ));
+    connect( optionLink, TQ_SIGNAL( clicked()), this, TQ_SLOT( enableControls() ));
+    connect( checkUndoScript, TQ_SIGNAL( clicked()), this, TQ_SLOT( enableControls() ));
 
-    connect( fileList, TQT_SIGNAL( updateCount()), this, TQT_SLOT( updateCount() ));
-    connect( fileList, TQT_SIGNAL( updatePreview()), this, TQT_SLOT( updatePreview() ));
-    connect( fileList, TQT_SIGNAL( deletePressed()), this, TQT_SLOT( removeFile() ));
-    connect( fileList, TQT_SIGNAL( addFiles()), this, TQT_SLOT( addFile() ));
-    connect( buttonUp, TQT_SIGNAL( clicked()), fileList, TQT_SLOT( moveUp() ));
-    connect( buttonDown, TQT_SIGNAL( clicked()), fileList, TQT_SLOT( moveDown() ));
-    connect( buttonUp, TQT_SIGNAL( clicked()), this, TQT_SLOT( updatePreview() ));
-    connect( buttonDown, TQT_SIGNAL( clicked()), this, TQT_SLOT( updatePreview() ));
-    connect( buttonUp2, TQT_SIGNAL( clicked()), this, TQT_SLOT( moveUp() ));
-    connect( buttonDown2, TQT_SIGNAL( clicked()), this, TQT_SLOT( moveDown() ));
-    connect( buttonReplace, TQT_SIGNAL( clicked()), this, TQT_SLOT( replace() ));
-    connect( buttonEasyReplace, TQT_SIGNAL( clicked()), this, TQT_SLOT( replace() ));
-    connect( buttonCoord, TQT_SIGNAL( clicked()), this, TQT_SLOT( getCoordinates() ));
-    connect( comboSort, TQT_SIGNAL( activated(int)), fileList, TQT_SLOT( setSorting(int) ));
+    connect( fileList, TQ_SIGNAL( updateCount()), this, TQ_SLOT( updateCount() ));
+    connect( fileList, TQ_SIGNAL( updatePreview()), this, TQ_SLOT( updatePreview() ));
+    connect( fileList, TQ_SIGNAL( deletePressed()), this, TQ_SLOT( removeFile() ));
+    connect( fileList, TQ_SIGNAL( addFiles()), this, TQ_SLOT( addFile() ));
+    connect( buttonUp, TQ_SIGNAL( clicked()), fileList, TQ_SLOT( moveUp() ));
+    connect( buttonDown, TQ_SIGNAL( clicked()), fileList, TQ_SLOT( moveDown() ));
+    connect( buttonUp, TQ_SIGNAL( clicked()), this, TQ_SLOT( updatePreview() ));
+    connect( buttonDown, TQ_SIGNAL( clicked()), this, TQ_SLOT( updatePreview() ));
+    connect( buttonUp2, TQ_SIGNAL( clicked()), this, TQ_SLOT( moveUp() ));
+    connect( buttonDown2, TQ_SIGNAL( clicked()), this, TQ_SLOT( moveDown() ));
+    connect( buttonReplace, TQ_SIGNAL( clicked()), this, TQ_SLOT( replace() ));
+    connect( buttonEasyReplace, TQ_SIGNAL( clicked()), this, TQ_SLOT( replace() ));
+    connect( buttonCoord, TQ_SIGNAL( clicked()), this, TQ_SLOT( getCoordinates() ));
+    connect( comboSort, TQ_SIGNAL( activated(int)), fileList, TQ_SLOT( setSorting(int) ));
     
-    connect( filename, TQT_SIGNAL( delayedTextChanged() ), this, TQT_SLOT( updatePreview() ));
-    connect( extemplate, TQT_SIGNAL( delayedTextChanged() ), this, TQT_SLOT( updatePreview() ));
-    connect( checkExtension, TQT_SIGNAL( clicked()), this, TQT_SLOT( updatePreview() ));
-    connect( comboExtension, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( updatePreview() ));
-    connect( checkPreview, TQT_SIGNAL( clicked()), this, TQT_SLOT( toggleImagePreview() ));
-    connect( preview, TQT_SIGNAL( itemChanged() ), this, TQT_SLOT( updatePreview() ));
-    connect( preview, TQT_SIGNAL( removeItem(int) ), this, TQT_SLOT( removeFile(int) ));
-    connect( preview, TQT_SIGNAL( addFile() ), this, TQT_SLOT( addFile() ));
-    connect( undorequester, TQT_SIGNAL( urlSelected(const TQString &)), this, TQT_SLOT( changeUndoScriptName() ));
-    connect( kapp, TQT_SIGNAL( aboutToQuit() ), this, TQT_SLOT( saveConfig() ) );
-    connect( buttonMove, TQT_SIGNAL( clicked()), fileList, TQT_SLOT( moveMode() ));
-    connect( checkName, TQT_SIGNAL( clicked()), this, TQT_SLOT( toggleName() ));
-    connect( buttonNumber, TQT_SIGNAL( clicked()), this, TQT_SLOT( changeNumbers() ));
+    connect( filename, TQ_SIGNAL( delayedTextChanged() ), this, TQ_SLOT( updatePreview() ));
+    connect( extemplate, TQ_SIGNAL( delayedTextChanged() ), this, TQ_SLOT( updatePreview() ));
+    connect( checkExtension, TQ_SIGNAL( clicked()), this, TQ_SLOT( updatePreview() ));
+    connect( comboExtension, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( updatePreview() ));
+    connect( checkPreview, TQ_SIGNAL( clicked()), this, TQ_SLOT( toggleImagePreview() ));
+    connect( preview, TQ_SIGNAL( itemChanged() ), this, TQ_SLOT( updatePreview() ));
+    connect( preview, TQ_SIGNAL( removeItem(int) ), this, TQ_SLOT( removeFile(int) ));
+    connect( preview, TQ_SIGNAL( addFile() ), this, TQ_SLOT( addFile() ));
+    connect( undorequester, TQ_SIGNAL( urlSelected(const TQString &)), this, TQ_SLOT( changeUndoScriptName() ));
+    connect( kapp, TQ_SIGNAL( aboutToQuit() ), this, TQ_SLOT( saveConfig() ) );
+    connect( buttonMove, TQ_SIGNAL( clicked()), fileList, TQ_SLOT( moveMode() ));
+    connect( checkName, TQ_SIGNAL( clicked()), this, TQ_SLOT( toggleName() ));
+    connect( buttonNumber, TQ_SIGNAL( clicked()), this, TQ_SLOT( changeNumbers() ));
 
     // Load Configuration
     loadConfig();
@@ -287,7 +287,7 @@ void KRenameImpl::parseCommandline()
 
         if( fileList->count() ) 
             // start renaming
-            TQTimer::singleShot( 200, this, TQT_SLOT( start() ) );
+            TQTimer::singleShot( 200, this, TQ_SLOT( start() ) );
     }
 }
 
@@ -300,23 +300,23 @@ void KRenameImpl::setupActions()
     KHelpMenu* mnuHelp = new KHelpMenu( parent );
 
     menuBar->insertItem( i18n("E&xtras"), mnuExtra );
-    mnuExtra->insertItem( i18n("&Profiles..."), this, TQT_SLOT( manageProfiles() ) );
+    mnuExtra->insertItem( i18n("&Profiles..."), this, TQ_SLOT( manageProfiles() ) );
     mnuExtra->insertSeparator();
-    mnuExtra->insertItem( SmallIcon("edit-undo"), i18n("&Undo Old Renaming Action..."), this, TQT_SLOT( undo() ) );
+    mnuExtra->insertItem( SmallIcon("edit-undo"), i18n("&Undo Old Renaming Action..."), this, TQ_SLOT( undo() ) );
     menuBar->insertItem( i18n("&Settings"), mnuSettings );
     menuBar->insertSeparator();
     menuBar->insertItem( i18n("&Help"), mnuHelp->menu() );
 
-    TDEAction* prefAct = KStdAction::preferences( this, TQT_SLOT(preferences()), actionCollection );
-    loadPlugins = new TDEAction( i18n("&Load TDE file plugins"), 0, this, TQT_SLOT( loadFilePlugins() ), actionCollection );
-    TDEAction* reloadAct = new TDEAction( i18n("&Reload Plugin Data"), 0, this, TQT_SLOT( reloadFilePluginData() ), actionCollection );
+    TDEAction* prefAct = KStdAction::preferences( this, TQ_SLOT(preferences()), actionCollection );
+    loadPlugins = new TDEAction( i18n("&Load TDE file plugins"), 0, this, TQ_SLOT( loadFilePlugins() ), actionCollection );
+    TDEAction* reloadAct = new TDEAction( i18n("&Reload Plugin Data"), 0, this, TQ_SLOT( reloadFilePluginData() ), actionCollection );
     
     prefAct->plug( mnuSettings );
     mnuSettings->insertSeparator();
     loadPlugins->plug( mnuSettings );
     reloadAct->plug( mnuSettings );
     
-    connect( mnuHelp, TQT_SIGNAL(showAboutApplication()), this, TQT_SLOT(about()));
+    connect( mnuHelp, TQ_SIGNAL(showAboutApplication()), this, TQ_SLOT(about()));
 }
 
 void KRenameImpl::setupPages()
@@ -422,7 +422,7 @@ void KRenameImpl::setupPage2()
 
     groupOptions = new TQButtonGroup( page_2 );
     groupOptions->setTitle( i18n( "O&ptions" ) );
-    groupOptions->setColumnLayout(0, Qt::Vertical );
+    groupOptions->setColumnLayout(0, TQt::Vertical );
     groupOptions->layout()->setSpacing( 6 );
     groupOptions->layout()->setMargin( 11 );
     groupOptionsLayout = new TQVBoxLayout( groupOptions->layout() );
@@ -721,16 +721,16 @@ void KRenameImpl::setupFileTab2()
     
     enableControls();
         
-    connect( comboPrefix, TQT_SIGNAL( textChanged( const TQString &)), this, TQT_SLOT( changed()));
-    connect( comboSuffix, TQT_SIGNAL( textChanged( const TQString &)), this, TQT_SLOT( changed()));
-    connect( comboKRenameFilename, TQT_SIGNAL( activated(int)), this, TQT_SLOT( changed()));
-    connect( comboCustom, TQT_SIGNAL( textChanged( const TQString & ) ), this, TQT_SLOT( changed() ));
-    connect( comboKRenamePrefix, TQT_SIGNAL(activated(int)), this, TQT_SLOT(changed()));
-    connect( comboKRenameExtension, TQT_SIGNAL( activated(int)), this, TQT_SLOT( changed()));
-    connect( comboCustomExtension, TQT_SIGNAL( textChanged( const TQString & ) ), this, TQT_SLOT( changed() ));
-    connect( comboKRenameSuffix, TQT_SIGNAL(activated(int)), this, TQT_SLOT(changed()));
-    connect( spinNull, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( changed() ));
-    connect( spinStart, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( changed() ));   
+    connect( comboPrefix, TQ_SIGNAL( textChanged( const TQString &)), this, TQ_SLOT( changed()));
+    connect( comboSuffix, TQ_SIGNAL( textChanged( const TQString &)), this, TQ_SLOT( changed()));
+    connect( comboKRenameFilename, TQ_SIGNAL( activated(int)), this, TQ_SLOT( changed()));
+    connect( comboCustom, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( changed() ));
+    connect( comboKRenamePrefix, TQ_SIGNAL(activated(int)), this, TQ_SLOT(changed()));
+    connect( comboKRenameExtension, TQ_SIGNAL( activated(int)), this, TQ_SLOT( changed()));
+    connect( comboCustomExtension, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( changed() ));
+    connect( comboKRenameSuffix, TQ_SIGNAL(activated(int)), this, TQ_SLOT(changed()));
+    connect( spinNull, TQ_SIGNAL( valueChanged(int) ), this, TQ_SLOT( changed() ));
+    connect( spinStart, TQ_SIGNAL( valueChanged(int) ), this, TQ_SLOT( changed() ));   
         
     buttonEasy1->setIconSet( SmallIcon("help") );
     buttonEasy2->setIconSet( SmallIcon("help") );
@@ -744,10 +744,10 @@ void KRenameImpl::setupFileTab2()
     
     const TQString easy_text( i18n("<qt>Insert a special KRename command which inserts file information into the filename.</qt>") );
     
-    connect( buttonEasy1, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotEasy1() ) );
-    connect( buttonEasy2, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotEasy2() ) );
-    connect( buttonEasy3, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotEasy3() ) );
-    connect( buttonEasy4, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotEasy4() ) );
+    connect( buttonEasy1, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEasy1() ) );
+    connect( buttonEasy2, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEasy2() ) );
+    connect( buttonEasy3, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEasy3() ) );
+    connect( buttonEasy4, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotEasy4() ) );
     
     TQToolTip::add( buttonEasy1, easy_text );
     TQToolTip::add( buttonEasy2, easy_text );
@@ -899,8 +899,8 @@ void KRenameImpl::setupTab1()
             gLayout = new TQVBoxLayout( g, 11, 6, "gLayout" );
 
             (*it)->check = new TQCheckBox( i18n("&Use this plugin"), parent );
-            connect( (*it)->check, TQT_SIGNAL( clicked() ), this, TQT_SLOT( pluginHelpChanged() ) );
-            connect( (*it)->plugin, TQT_SIGNAL( previewChanged( Plugin* ) ), this, TQT_SLOT( updatePluginPreview( Plugin* ) ) );
+            connect( (*it)->check, TQ_SIGNAL( clicked() ), this, TQ_SLOT( pluginHelpChanged() ) );
+            connect( (*it)->plugin, TQ_SIGNAL( previewChanged( Plugin* ) ), this, TQ_SLOT( updatePluginPreview( Plugin* ) ) );
             Layout->addWidget( (*it)->check );
             (*it)->plugin->drawInterface( g, gLayout );
 
@@ -1641,7 +1641,7 @@ void KRenameImpl::changeParent( TQWidget* p, KMenuBar* m, TQPushButton* finish,
     menuBar = m;
     finishButton = finish;
 
-    connect( finishButton, TQT_SIGNAL( clicked()), this, TQT_SLOT( start() ));
+    connect( finishButton, TQ_SIGNAL( clicked()), this, TQ_SLOT( start() ));
 
     if( !r.isNull() ) {
         parent->resize( r.size() );
