@@ -17,13 +17,13 @@
 
 #include "permission.h"
 
-// QT includes
+// TQt includes
 #include <tqcheckbox.h>
 #include <tqgroupbox.h>
 #include <tqlabel.h>
 #include <tqlayout.h>
 
-// KDE includes
+// TDE includes
 #include <tdeapplication.h>
 #include <kcombobox.h>
 #include <kiconloader.h>
@@ -136,7 +136,7 @@ void MyPermPlugin::drawInterface( TQWidget* w, TQVBoxLayout* l )
 
     groupOwner = new TQGroupBox ( i18n("Ownership"), w );
     groupOwner->setEnabled( FALSE );
-    groupOwner->setColumnLayout(0, Qt::Vertical );
+    groupOwner->setColumnLayout(0, TQt::Vertical );
     groupOwner->layout()->setSpacing( 6 );
     groupOwner->layout()->setMargin( 11 );
     groupOwnerLayout = new TQVBoxLayout( groupOwner->layout() );
@@ -222,8 +222,8 @@ void MyPermPlugin::drawInterface( TQWidget* w, TQVBoxLayout* l )
     l->addWidget( groupOwner );
     l->addItem( spacer10 );
 
-    connect( checkOwner, TQT_SIGNAL(clicked()), this, TQT_SLOT(enableControls()) );
-    connect( checkPermissions, TQT_SIGNAL(clicked()), this, TQT_SLOT(enableControls()) );
+    connect( checkOwner, TQ_SIGNAL(clicked()), this, TQ_SLOT(enableControls()) );
+    connect( checkPermissions, TQ_SIGNAL(clicked()), this, TQ_SLOT(enableControls()) );
 }
 
 void MyPermPlugin::fillStructure()
@@ -244,12 +244,12 @@ TQString MyPermPlugin::processFile( BatchRenamer* b, int i, TQString, int )
 {
     TQString filename = b->files()[i].dst.name;
     if( perm.changePermissions )
-        if( chmod( (const char *)filename, (mode_t)perm.newPermission ) == -1 )
-            return TQString( i18n("Can't chmod %1.") ).arg(filename);
+        if (chmod(filename.local8Bit(), (mode_t)perm.newPermission) == -1)
+            return i18n("Can't chmod %1.").arg(filename);
 
     if( perm.changeOwner )
-        if( chown( (const char*)filename, getUid( perm.owner), getGid( perm.group )))
-            return TQString( i18n("Can't chown %1.") ).arg(filename);
+        if (chown(filename.local8Bit(), getUid(perm.owner), getGid(perm.group)))
+            return i18n("Can't chown %1.").arg(filename);
 
     return TQString();
 }
@@ -295,7 +295,7 @@ int MyPermPlugin::getGid( TQString group )
     struct group *ge;
     setgrent();
     for (i=0; ((ge = getgrent()) != 0L) && (i < MAXENTRIES); i++)
-        if( !strcmp( ge->gr_name, (const char *)group ) )
+        if (!strcmp(ge->gr_name, group.local8Bit()))
             break;
     r = ge->gr_gid;
     endgrent();
@@ -308,7 +308,7 @@ int MyPermPlugin::getUid( TQString owner )
     struct passwd *user;
     setpwent();
     for (i=0; ((user = getpwent()) != 0L) && (i < MAXENTRIES); i++)
-        if( !strcmp(user->pw_name, (const char *)owner) )
+        if (!strcmp(user->pw_name, owner.local8Bit()))
             break;
     r = user->pw_uid;
     endpwent();
@@ -326,4 +326,4 @@ const TQPixmap MyPermPlugin::getIcon() const
     return kapp->iconLoader()->loadIcon( "clanbomber", TDEIcon::Small );
 }
 
-
+#include "permission.moc"
