@@ -30,7 +30,7 @@ class TQGridLayout;
 class TQLabel;
 class UndoDialog : public KDialogBase
 { 
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         UndoDialog( TQWidget* parent = 0 );
